/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.financial.erpcredit.service;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.sg.financial.erpcredit.entity.*;
import com.jeeplus.modules.sg.financial.erpcredit.mapper.ErpCreditChild1Mapper;
import com.jeeplus.modules.sg.financial.erpcredit.mapper.ErpCreditChild2Mapper;
import com.jeeplus.modules.sg.financial.erpcredit.mapper.ErpCreditMapper;
import com.jeeplus.modules.sg.financial.erpcredit.util.ExportTemplate;
import com.jeeplus.modules.sg.financial.erpcredit.util.ExportUtil2;
import com.jeeplus.modules.sg.financial.settlement.entity.MaintainData;
import com.jeeplus.modules.sg.financial.settlement.mapper.DataMaintenanceMapper;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URLEncoder;
import java.util.List;


@Service
@Transactional(readOnly = true)
public class ErpCreditService extends CrudService<ErpCreditMapper,ErpCredit> {
    @Autowired
    private ErpCreditChild1Mapper erpCreditChild1Mapper;
    @Autowired
    private ErpCreditChild2Mapper erpCreditChild2Mapper;
    @Autowired
    private ErpCreditMapper erpCreditMapper;
    @Autowired
    private DataMaintenanceMapper dataMaintenanceMapper;

    public List<ErpCredit> getListErpCredit(String[] ids){
        List<ErpCredit> erpCreditList = erpCreditMapper.findErpCreditList(ids);
        List<ErpCreditChild1> erpCreditChild1List = erpCreditChild1Mapper.findErpCreditChild1List(ids);
        List<ErpCreditChild2> erpCreditChild2List = erpCreditChild2Mapper.findErpCreditChild2List(ids);
        if (null!=erpCreditList&&erpCreditList.size()>0){
            for (ErpCredit erpCredit:erpCreditList){
                if (null!=erpCreditChild1List&&erpCreditChild1List.size()>0){
                    for (ErpCreditChild1 erpCreditChild1:erpCreditChild1List){
                        if (erpCredit.getId().equals(erpCreditChild1.getErpCredit().getId())){
                            erpCredit.getErpCreditChild1s().add(erpCreditChild1);
                        }
                    }
                }
                if (null!=erpCreditChild2List&&erpCreditChild2List.size()>0){
                    for (ErpCreditChild2 erpCreditChild2:erpCreditChild2List){
                        if (erpCredit.getId().equals(erpCreditChild2.getErpCredit().getId())){
                            erpCredit.getErpCreditChild2s().add(erpCreditChild2);
                        }
                    }
                }
            }
        }
        return erpCreditList;
    }
    public ErpCredit get(String id) {
        ErpCredit erpCredit = super.get(id);
        erpCredit.setErpCreditChild1s(erpCreditChild1Mapper.findList(new ErpCreditChild1(erpCredit)));
        erpCredit.setErpCreditChild2s(erpCreditChild2Mapper.findList(new ErpCreditChild2(erpCredit)));
//        erpCredit.setErpCreditChild3s(erpCreditChild3Mapper.findList(new ErpCreditChild3(erpCredit)));
        return erpCredit;
    }

    public List<ErpCredit> findList(ErpCredit erpCredit) {
        return super.findList(erpCredit);
    }

    public Page<ErpCredit> findPage(Page<ErpCredit> page, ErpCredit erpCredit) {
        return super.findPage(page, erpCredit);
    }

    @Transactional(readOnly = false)
    public void save(ErpCredit erpCredit) {
        super.save(erpCredit);
        for (ErpCreditChild1 erpCreditChild1 : erpCredit.getErpCreditChild1s()){
            if (ErpCreditChild1.DEL_FLAG_NORMAL.equals(erpCredit.getDelFlag())){
                if (StringUtils.isBlank(erpCreditChild1.getId())) {
                    erpCreditChild1.setErpCredit(erpCredit);
                    erpCreditChild1.preInsert();
                    erpCreditChild1Mapper.insert(erpCreditChild1);
                }else {
                    erpCreditChild1.preUpdate();
                    erpCreditChild1Mapper.update(erpCreditChild1);
                }
            }else {
                erpCreditChild1Mapper.delete(erpCreditChild1);
            }
        }
        for (ErpCreditChild2 erpCreditChild2 : erpCredit.getErpCreditChild2s()){
            if (ErpCreditChild2.DEL_FLAG_NORMAL.equals(erpCreditChild2.getDelFlag())){
                if (StringUtils.isBlank(erpCreditChild2.getId())){
                    erpCreditChild2.setErpCredit(erpCredit);
                    erpCreditChild2.preInsert();
                    erpCreditChild2Mapper.insert(erpCreditChild2);
                }else {
                    erpCreditChild2.preUpdate();
                    erpCreditChild2Mapper.update(erpCreditChild2);
                }
            }else {
                erpCreditChild2Mapper.delete(erpCreditChild2);
            }
        }
//        for (ErpCreditChild3 erpCreditChild3 : erpCredit.getErpCreditChild3s()){
//            if (ErpCreditChild3.DEL_FLAG_NORMAL.equals(erpCreditChild3.getDelFlag())){
//                if (StringUtils.isBlank(erpCreditChild3.getId())){
//                    erpCreditChild3.setErpCredit(erpCredit);
//                    erpCreditChild3.preInsert();
//                    erpCreditChild3Mapper.insert(erpCreditChild3);
//                }else {
//                    erpCreditChild3.preUpdate();
//                    erpCreditChild3Mapper.update(erpCreditChild3);
//                }
//            }else {
//                erpCreditChild3Mapper.delete(erpCreditChild3);
//            }
//        }
    }

    @Transactional(readOnly = false)
    public void delete(ErpCredit erpCredit) {
        super.delete(erpCredit);
        erpCreditChild1Mapper.delete(new ErpCreditChild1(erpCredit));
        erpCreditChild2Mapper.delete(new ErpCreditChild2(erpCredit));
//        erpCreditChild3Mapper.delete(new ErpCreditChild3(erpCredit));
    }

    //维护表
    public List<MaintainData> getFindListMain(String[] ids){
        return dataMaintenanceMapper.getFindListMain(ids);
    }

    //导出
    public void getExport(String[] ids, HttpServletResponse response){
        List<ErpCredit> erpCreditList = getListErpCredit(ids);
        List<MaintainData> maintainDatas = getFindListMain(ids);
        for (MaintainData maintainData:maintainDatas){
            System.out.println("11123123====="+maintainData);
        }
        ExportTemplate exportTemplate = new ExportTemplate();
        File newFile = exportTemplate.createNewFile();
        // 新文件写入数据，并下载
        InputStream inputStream = null;
        XSSFWorkbook workbook = null;
        XSSFSheet sheet1 = null;
        XSSFSheet sheet3 = null;
        XSSFSheet sheet5 = null;
        XSSFSheet sheet4 = null;
        XSSFSheet sheet6=null;
        XSSFSheet sheet7=null;
        XSSFSheet sheet10=null;
        XSSFSheet sheet11=null;
        try {
            inputStream = new FileInputStream(newFile);// 将excel文件转为输入流
            workbook = new XSSFWorkbook(inputStream);// 创建个workbook，
            sheet1 =workbook.getSheetAt(1);
            sheet3 = workbook.getSheetAt(3);
            sheet4 = workbook.getSheetAt(4);
            sheet5=workbook.getSheetAt(5);
            sheet6=workbook.getSheetAt(6);
            sheet7=workbook.getSheetAt(7);
            sheet10=workbook.getSheetAt(10);
            sheet11=workbook.getSheetAt(11);
        } catch (Exception e1) {
            e1.printStackTrace();
        }
        try {
            // 写数据
            FileOutputStream fos = new FileOutputStream(newFile);
            ExportUtil2.getSheet1(sheet1,erpCreditList,maintainDatas);
            ExportUtil2.getSheet3(sheet3,erpCreditList);
            ExportUtil2.getSheet5(sheet5,erpCreditList);
            ExportUtil2.getSheet6(sheet6,erpCreditList);
            ExportUtil2.getSheet7(sheet7,erpCreditList);
            ExportUtil2.getSheet10(sheet10,erpCreditList);
            ExportUtil2.getSheet11(sheet11,erpCreditList);
            ExportUtil2.getSheet4(sheet4,erpCreditList);
            workbook.write(fos);
            fos.flush();
            fos.close();
            InputStream fis = new BufferedInputStream(new FileInputStream(
                    newFile));
            byte[] buffer = new byte[fis.available()];
            fis.read(buffer);
            fis.close();
            response.reset();
            response.setContentType("text/html;charset=UTF-8");
            OutputStream toClient = new BufferedOutputStream(response.getOutputStream());
            response.setContentType("application/x-msdownload");
            String newName = URLEncoder.encode("竣工结算表" + System.currentTimeMillis() + ".xlsx","UTF-8");
            response.addHeader("Content-Disposition","attachment;filename=\"" + newName + "\"");
            response.addHeader("Content-Length", "" + newFile.length());
            toClient.write(buffer);
            toClient.flush();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (null != inputStream) {
                    inputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        // 删除创建的新文件
        // this.deleteFile(newFile);
    }
}